markuptools.get_down_markup_attached_to_component
=================================================

.. autofunction:: abjad.tools.markuptools.get_down_markup_attached_to_component.get_down_markup_attached_to_component
